@@ -84,11 +84,11 @@ setMethod("fit",
 					lin.l <- c(lin.l,conrows.lower)
 				}
 			}
-			
+						
 			# select only those columns of the constraint matrix that correspond to non-fixed parameters
 			linconFull <- lincon
-			lincon <- lincon[,!fixed]
-			
+			lincon <- lincon[,!fixed,drop=FALSE]
+						
 			# set donlp2 control parameters
 			cntrl <- donlp2.control(hessian=FALSE,difftype=2,report=TRUE)	
 			
