@@ -14,7 +14,7 @@ setMethod("logDens","BINOMresponse",
 			dbinom(x=object@y[,1],size=rowSums(object@y),prob=predict(object),log=TRUE)
 		} else {
 			if(!NCOL(object@y==1)) stop("not a valid response matrix for BINOMresponse")
-			dbinom(x=object@y,prob=predict(object),log=TRUE)
+			dbinom(x=object@y,size=1,prob=predict(object),log=TRUE)
 		}
 	}
 )
@@ -25,7 +25,7 @@ setMethod("dens","BINOMresponse",
 			dbinom(x=object@y[,1],size=rowSums(object@y),prob=predict(object),log=log)
 		} else {
 			if(!NCOL(object@y==1)) stop("not a valid response matrix for BINOMresponse")
-			dbinom(x=object@y,prob=predict(object),log=log)
+			dbinom(x=object@y,size=1,prob=predict(object),log=log)
 		}
 	}
 )
