@@ -16,16 +16,16 @@ setMethod("fit","MULTINOMresponse",
 		Wts[-1,] <- t(pars$coefficients) # set starting weights
 		if(!is.null(w)) {
 			if(NCOL(y) < 3) {
-        fit <- nnet.default(x,y,weights=w,size=0,entropy=TRUE,skip=TRUE,mask=mask,Wts=Wts,trace=FALSE)
-      } else {
-        fit <- nnet.default(x,y,weights=w,size=0,softmax=TRUE,skip=TRUE,mask=mask,Wts=Wts,trace=FALSE)
-      }
+				fit <- nnet.default(x,y,weights=w,size=0,entropy=TRUE,skip=TRUE,mask=mask,Wts=Wts,trace=FALSE)
+			} else {
+				fit <- nnet.default(x,y,weights=w,size=0,softmax=TRUE,skip=TRUE,mask=mask,Wts=Wts,trace=FALSE)
+			}
 		} else {
-		  if(NCOL(y) < 3) {
-        fit <- nnet.default(x,y,size=0,entropy=TRUE,skip=TRUE,mask=mask,Wts=Wts,trace=FALSE)
-      } else {
-        fit <- nnet.default(x,y,size=0,softmax=TRUE,skip=TRUE,mask=mask,Wts=Wts,trace=FALSE)
-      }
+			if(NCOL(y) < 3) {
+				fit <- nnet.default(x,y,size=0,entropy=TRUE,skip=TRUE,mask=mask,Wts=Wts,trace=FALSE)
+			} else {
+				fit <- nnet.default(x,y,size=0,softmax=TRUE,skip=TRUE,mask=mask,Wts=Wts,trace=FALSE)
+			}
 		}
 		pars$coefficients <- t(matrix(fit$wts,ncol=ncol(pars$coefficients),nrow=nrow(pars$coefficients)+1)[-1,])
 		object <- setpars(object,unlist(pars))
@@ -56,19 +56,21 @@ setMethod("predict","MULTINOMresponse",
 )
 
 setMethod("simulate",signature(object="MULTINOMresponse"),
-  function(object,nsim=1,seed=NULL,times) {
-    if(!is.null(seed)) set.seed(seed)
-    if(missing(times)) {
-      # draw all times in one go
-      pr <- predict(object)
-    } else {
-      pr <- predict(object)[times,]
-      if(length(times)==1) pr <- matrix(pr,ncol=length(pr))
-    }
-    nt <- nrow(pr)
-    sims <- array(apply(pr,1,rmultinom,n=nsim,size=1),dim=c(ncol(pr),nsim,nt))
-    sims <- matrix(aperm(sims,c(3,2,1)),nrow=nsim*nt,ncol=ncol(pr))
-    #response <- t(apply(sims,c(2,3), function(x) which(x==1)))
-    return(sims)
-  }
+	function(object,nsim=1,seed=NULL,times) {
+		if(!is.null(seed)) set.seed(seed)
+		if(missing(times)) {
+			# draw all times in one go
+			pr <- predict(object)
+			n <- rowSums(object@y)
+		} else {
+			pr <- predict(object)[times,]
+			n <- rowSums(object@y)[times]
+			if(length(times)==1) pr <- matrix(pr,ncol=length(pr))
+		}
+		nt <- nrow(pr)
+		sims <- array(apply(pr,1,rmultinom,n=nsim,size=n),dim=c(ncol(pr),nsim,nt))
+		sims <- matrix(aperm(sims,c(3,2,1)),nrow=nsim*nt,ncol=ncol(pr))
+		#response <- t(apply(sims,c(2,3), function(x) which(x==1)))
+		return(sims)
+	}
 )
