@@ -19,7 +19,7 @@ setMethod("transInit",
 		mf[[1]] <- as.name("model.frame")
 		mf <- eval(mf, parent.frame())
 		x <- model.matrix(attr(mf, "terms"),mf)
-		y <- matrix(1,ncol=1) # y is not needed in the transition and init models		    
+		y <- matrix(1,ncol=1) # y is not needed in the transition and init models
 		parameters <- list()
 		if(is.null(nstates)) stop("'nstates' must be provided in call to trinModel")
 		if(family$family=="multinomial") {
@@ -44,7 +44,7 @@ setMethod("transInit",
 				} else {
 					parameters$coefficients[1,] <- pstart[1:ncol(parameters$coefficients)]
 				}
-				pstart <- matrix(pstart,,ncol(x),byrow=TRUE)
+				pstart <- matrix(pstart,ncol(x),byrow=TRUE)
 				if(ncol(x)>1) parameters$coefficients[2:ncol(x),] <- pstart[2:ncol(x),]
 			} else {
 				if(family$link=="identity") parameters$coefficients <- family$linkfun(pstart[1:length(parameters$coefficients)])
@@ -73,8 +73,16 @@ setMethod("dens","transInit",
 )
 
 setMethod("predict","transInit",
-	function(object) {
-		object@family$linkinv(object@x%*%object@parameters$coefficients,base=object@family$base)
+	function(object,newx) {
+		if(missing(newx)) {
+			if(object@family$link=="identity") object@family$linkinv(object@x%*%object@parameters$coefficients)
+			else object@family$linkinv(object@x%*%object@parameters$coefficients,base=object@family$base)
+		} else {
+			if(!(is.matrix(newx))) stop("'newx' must be matrix in predict (GLMresponse)")
+			if(!(ncol(newx)==nrow(object@parameters$coefficients))) stop("Incorrect dimension of 'newx' in predict (GLMresponse)")
+			if(object@family$link=="identity") object@family$linkinv(newx%*%object@parameters$coefficients)
+			else object@family$linkinv(newx%*%object@parameters$coefficients,base=object@family$base)
+		}
 	}
 )
 
@@ -99,7 +107,6 @@ setMethod("fit","transInit",
 			#y <- round(y) # delete me
 			if(!is.null(w)) w <- w[-na]
 		}
-
 		mask <- matrix(1,nrow=nrow(pars$coefficients),ncol=ncol(pars$coefficients))
 		mask[,base] <- 0 # fix base category coefficients to 0
 		mask <- rbind(0,mask) # fix "bias" nodes to 0
@@ -108,18 +115,18 @@ setMethod("fit","transInit",
 		Wts[Wts == Inf] <- .Machine$double.max.exp # Fix this!!!!
 		Wts[Wts == -Inf] <- .Machine$double.min.exp # Fix this!!!!!
 		if(!is.null(w)) {
-      if(NCOL(y) < 3) {
-        fit <- nnet.default(x,y,weights=w,size=0,entropy=TRUE,skip=TRUE,mask=mask,Wts=Wts,trace=FALSE)
-      } else {
-        fit <- nnet.default(x,y,weights=w,size=0,softmax=TRUE,skip=TRUE,mask=mask,Wts=Wts,trace=FALSE)
-      }
-    } else {
-      if(NCOL(y) < 3) {
-        fit <- nnet.default(x,y,size=0,entropy=TRUE,skip=TRUE,mask=mask,Wts=Wts,trace=FALSE)
-      } else {
-        fit <- nnet.default(x,y,size=0,softmax=TRUE,skip=TRUE,mask=mask,Wts=Wts,trace=FALSE)
-      }
-    }
+			if(NCOL(y) < 3) {
+				fit <- nnet.default(x,y,weights=w,size=0,entropy=TRUE,skip=TRUE,mask=mask,Wts=Wts,trace=FALSE)
+			} else {
+				fit <- nnet.default(x,y,weights=w,size=0,softmax=TRUE,skip=TRUE,mask=mask,Wts=Wts,trace=FALSE)
+			}
+		} else {
+			if(NCOL(y) < 3) {
+				fit <- nnet.default(x,y,size=0,entropy=TRUE,skip=TRUE,mask=mask,Wts=Wts,trace=FALSE)
+			} else {
+				fit <- nnet.default(x,y,size=0,softmax=TRUE,skip=TRUE,mask=mask,Wts=Wts,trace=FALSE)
+			}
+		}
 		pars$coefficients <- t(matrix(fit$wts,ncol=ncol(pars$coefficients),nrow=nrow(pars$coefficients)+1)[-1,])
 		object <- setpars(object,unlist(pars))
 		object
@@ -127,26 +134,26 @@ setMethod("fit","transInit",
 )
 
 setMethod("simulate",signature(object="transInit"),
-  function(object,nsim=1,seed=NULL,times,is.prior=FALSE,...) {
-    if(!is.null(seed)) set.seed(seed)
-    if(is.prior) {
-      pr <- dens(object)
-      sims <- array(apply(pr,1,rmultinom,n=nsim,size=1),dim=c(ncol(pr),nsim,nrow(pr)))
-      states <- t(apply(sims,c(2,3), function(x) which(x==1)))
-      return(states)
-    } else {
-      if(missing(times)) {
-        # this is likely to be a stationary model...
-        pr <- predict(object)
-      } else {
-        pr <- predict(object)[times,]
-        if(length(times)==1) pr <- matrix(pr,ncol=length(pr))
-      }
-      nt <- nrow(pr)
-      sims <- array(apply(pr,1,rmultinom,n=nsim,size=1),dim=c(ncol(pr),nsim,nt))
-      states <- t(apply(sims,c(2,3), function(x) which(x==1)))
-      # states <- apply(apply(pr,2,rmultinom rmultinom(nt*nsim,size=1,prob=pr),2,function(x) which(x==1))
-      return(states)
-    }
-  }
+	function(object,nsim=1,seed=NULL,times,is.prior=FALSE,...) {
+		if(!is.null(seed)) set.seed(seed)
+		if(is.prior) {
+			pr <- dens(object)
+			sims <- array(apply(pr,1,rmultinom,n=nsim,size=1),dim=c(ncol(pr),nsim,nrow(pr)))
+			states <- t(apply(sims,c(2,3), function(x) which(x==1)))
+			return(states)
+		} else {
+			if(missing(times)) {
+				# this is likely to be a stationary model...
+				pr <- predict(object)
+			} else {
+				pr <- predict(object)[times,]
+				if(length(times)==1) pr <- matrix(pr,ncol=length(pr))
+			}
+			nt <- nrow(pr)
+			sims <- array(apply(pr,1,rmultinom,n=nsim,size=1),dim=c(ncol(pr),nsim,nt))
+			states <- t(apply(sims,c(2,3), function(x) which(x==1)))
+			# states <- apply(apply(pr,2,rmultinom rmultinom(nt*nsim,size=1,prob=pr),2,function(x) which(x==1))
+			return(states)
+		}
+	}
 )
\ No newline at end of file
